//
//  CirculoView.swift
//  Examen
//
//  Created by Santiago Pavón on 16/10/14.
//  Copyright (c) 2014 Santiago Pavón. All rights reserved.
//

import UIKit

@IBDesignable
class CirculoView: UIView {

    override func awakeFromNib() {
        addGestureRecognizer(UIPinchGestureRecognizer(target: self, action: "pinch:"))
        addGestureRecognizer(UITapGestureRecognizer(target: self, action: "tap:"))
        
        if let bimg = UIImage(named: "cloud") {
            backgroundColor = UIColor(patternImage: bimg)
        }
    }

    func pinch(sender:UIPinchGestureRecognizer) {
        let scale = Double(sender.scale)
        radio *= scale
        sender.scale = 1
    }
    
    func tap(sender:UITapGestureRecognizer) {
        hole = !hole
    }
    
    @IBInspectable
    var radio: Double = 100.0 {
        didSet {
            setNeedsDisplay()
        }
    }
    
    @IBInspectable
    var hole: Bool = true {
        didSet {
            setNeedsDisplay()
        }
    }
    
    @IBInspectable
    var fillColor: UIColor = UIColor.redColor() {
        didSet {
            setNeedsDisplay()
        }
    }

    override func drawRect(rect: CGRect)
    {
        let rect = CGRectMake(
            bounds.size.width/2 - CGFloat(radio),
            bounds.size.height/2 - CGFloat(radio),
            CGFloat(2*radio),
            CGFloat(2*radio))
        let path = UIBezierPath(ovalInRect: rect)

        if hole {
            let rect2 = CGRectMake(
                bounds.size.width/2 - CGFloat(radio/2),
                bounds.size.height/2 - CGFloat(radio/2),
                CGFloat(radio),
                CGFloat(radio))
            let path2 = UIBezierPath(ovalInRect: rect2)
            path.usesEvenOddFillRule = true
            path.appendPath(path2)
        }
        
        UIColor.blueColor().setStroke()
        fillColor.setFill()
        path.lineWidth = 3
        path.stroke()
        path.fill()
    }
}
